<?php
/**
*
* @package Sidebar
* @copyright (c) 2018 kaptangula
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*
*/

namespace kaptangula\sidebar\core;

class sidebar
{
	/** @var \phpbb\auth\auth */
	protected $auth;

	/** @var \phpbb\config\config */
	protected $config;

	/** @var \phpbb\cache\driver\driver_interface */
	protected $cache;

	/** @var \phpbb\content_visibility */
	protected $content_visibility;

	/** @var \phpbb\db\driver\driver_interface */
	protected $db;

	/* @var \phpbb\config\db_text $config_text */
	protected $config_text;

	/** @var \phpbb\event\dispatcher_interface */
	protected $dispatcher;

	/* @var \phpbb\controller\helper */
	protected $helper;

	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\user */
	protected $user;

	/** @var string phpBB root path */
	protected $phpbb_root_path;

	/** @var string PHP extension */
	protected $php_ext;

	public function __construct(
		\phpbb\auth\auth $auth,
		\phpbb\config\config $config,
		\phpbb\cache\service $cache,
		\phpbb\content_visibility $content_visibility,
		\phpbb\db\driver\driver_interface $db,
		\phpbb\config\db_text $config_text,
		\phpbb\event\dispatcher_interface $dispatcher,
		\phpbb\controller\helper $helper,
		\phpbb\template\template $template,
		\phpbb\user $user,
		$phpbb_root_path,
		$php_ext
	)
	{
		$this->auth = $auth;
		$this->config = $config;
		$this->cache = $cache;
		$this->content_visibility = $content_visibility;
		$this->db = $db;
		$this->config_text = $config_text;
		$this->dispatcher = $dispatcher;
		$this->helper = $helper;
		$this->template = $template;
		$this->user = $user;
		$this->root_path = $phpbb_root_path;
		$this->php_ext = $php_ext;
	}

	public function common_setup()
	{
		$sidebar_data = $this->config_text->get_array(array(
			'sidebar_text',
		));
		
		$this->template->assign_vars(array(
			'SIDEBAR_TEXT'     => htmlspecialchars_decode($sidebar_data['sidebar_text']),		
		));
	}

	// NEWMESSAGES BLOCK
	public function newmessages()
	{
		if( ( $newmessages = $this->cache->get('_recent_new_msg') ) === false )
		{	
			$msg_read_ary = array();
			$forum_read_ary = $this->auth->acl_getf('f_read');

			foreach ($forum_read_ary as $forum_id => $allowed)
			{
				if ($allowed['f_read'])
				{
					$msg_read_ary[] = (int) $forum_id;
				}
			}
			$msg_read_ary = array_unique($msg_read_ary);

			$msgnew = array(
				'SELECT'	=> 'p.post_id, p.post_visibility, p.poster_id, p.post_time, p.post_subject, p.forum_id, p.post_text, p.topic_id, p.bbcode_bitfield, p.bbcode_uid, p.enable_bbcode, p.enable_smilies, p.enable_magic_url, u.user_id, u.username, u.user_colour, u.user_type, u.user_avatar, u.user_avatar_type, u.user_avatar_width, u.user_avatar_height, t.topic_id, t.topic_title, t.forum_id, t.topic_last_post_id, t.topic_last_post_time',
				'FROM'		=> array(POSTS_TABLE => 'p'),
				'LEFT_JOIN'	=> array(
					array(
						'FROM'	=> array(TOPICS_TABLE => 't'),
						'ON'	=> 'p.topic_id = t.topic_id',
					),
					array(
						'FROM'	=> array(USERS_TABLE => 'u'),
						'ON'	=> 't.topic_last_poster_id = u.user_id',
					),
				),
				'WHERE'		=> 	'
				(
					p.topic_id  = t.topic_id
				)
					AND ( ' . $this->db->sql_in_set('t.forum_id', $msg_read_ary) . ')
					AND p.poster_id = u.user_id
					AND t.topic_status <> ' . ITEM_MOVED . '
					AND t.topic_visibility = 1
					AND t.forum_id <> 0',	
				'GROUP_BY'	=> 'post_id',
				'ORDER_BY'	=> 'post_time DESC',
			);

			$result = $this->db->sql_query_limit($this->db->sql_build_query('SELECT', $msgnew), 5);

			$newmessages = array();
			while ($row = $this->db->sql_fetchrow($result))
			{
				$newmessages[] = $row;
			}
	  
			$this->db->sql_freeresult($result);
			// Cache for 5 min.
			$this->cache->put('_recent_new_msg', $newmessages, 300);
		}
 
		foreach($newmessages as $row)
		{
	
			/* only auth'd users can view the profile */
			$top_users_string = ($this->auth->acl_get('u_viewprofile')) ? get_username_string('full', $row['user_id'], $row['username'], $row['user_colour']) : get_username_string('no_profile', $row['user_id'], $row['username'], $row['user_colour']);

			/* Let's show the TPOTM then.. */
			$new_msgs = (int) $row['post_text'];

			$avatar_size_size = $this->config['avatar_re_size'];
			$post_id = $row['post_id'];
			$uid = $bitfield = $options = '';
			$allow_bbcode = $allow_smilies = $allow_urls = true;
			$flags = (($allow_bbcode) ? OPTION_FLAG_BBCODE : 0) + (($allow_smilies) ? OPTION_FLAG_SMILIES : 0) + (($allow_urls) ? OPTION_FLAG_LINKS : 0);
			$message = generate_text_for_display($row['post_text'], $row['bbcode_uid'], $row['bbcode_bitfield'], $flags);
			$msg_chars  = '60';
			if ($msg_chars != 0 and utf8_strlen($message) > $msg_chars)
			{
				$allow_bbcode = $allow_smilies = $allow_urls = false;
				strip_bbcode($message, $row['bbcode_uid']);
				$msg_full = utf8_substr($message, 0, $msg_chars) . '...';
				$msg_full = $msg_full . '...'; 
				$post_link = append_sid("{$this->phpbb_root_path}viewtopic.$this->php_ext", "p=" . $post_id . "#p" . $post_id);
				$read_full = $this->user->lang['READ_FULL'];
			}
			else
			{
				$msg_full = $message;
				$post_link 	= '';
				$read_full 	= '';
			}

			$this->template->assign_block_vars('newest_msg',array(
				'LASTPOSTER_NAME'	=> $top_users_string,
				'TOPIC_TITLE'		=> $row['topic_title'],
				'DATE'				=> $this->user->format_date($row['post_time']),
				'TOP_MSG'			=> $msg_full,
				'L_READ_FULL'		=> $read_full,
				'U_READ_FULL'		=> $post_link,
				'POSTER_AVATAR' 	=>   ($row['user_avatar']) ? get_user_avatar($row['user_avatar'], $row['user_avatar_type'], ($row['user_avatar_width'] > $row['user_avatar_height']) ? $avatar_size_size : ($avatar_size_size / $row['user_avatar_height']) * $row['user_avatar_width'], ($row['user_avatar_height'] > $row['user_avatar_width']) ? $avatar_size_size : ($avatar_size_size / $row['user_avatar_width']) * $row['user_avatar_height']) : '',
			));
		}
	}
	// END NEWMESSAGES BLOCK
	// TOPUSERS BLOCK
	
	public function last_news()
	{
		if( ( $last_news = $this->cache->get('_recent_news') ) === false )
		{	
			$msg_read_ary = ($this->config['last_newsforum_id']) ? $this->config['last_newsforum_id'] : 0;
			$last_newsforum_id = array_map('intval', explode(',', $msg_read_ary));

			$sql_ary = array(
				'SELECT'	=> 'p.post_id, p.poster_id, p.post_text, p.post_time, p.topic_id, p.bbcode_bitfield, p.bbcode_uid, p.enable_bbcode, p.enable_smilies, p.enable_magic_url, u.user_id, u.username, u.user_colour, u.user_type, u.user_avatar, u.user_avatar_type, u.user_avatar_width, u.user_avatar_height, t.topic_id, t.topic_title, t.forum_id, t.topic_last_post_id, t.topic_last_post_time, t.topic_views',
					'FROM'		=> array(TOPICS_TABLE => 't', POSTS_TABLE => 'p'),
					'LEFT_JOIN'	=> array(
					array(
						'FROM'	=> array(USERS_TABLE => 'u'),
						'ON'	=> 'p.poster_id = u.user_id',
					),
				),
			'WHERE'		=> 't.topic_id = p.topic_id
				AND t.forum_id IN (' . $msg_read_ary . ')
				AND t.forum_id <> 0
				AND p.post_id = t.topic_first_post_id
				AND t.topic_status <> ' . ITEM_MOVED . '
				AND t.topic_visibility = 1
				AND t.forum_id <> 0',	
				'GROUP_BY'	=> 'post_id',
				'ORDER_BY'	=> 'post_time DESC',
			);

			$result = $this->db->sql_query_limit($this->db->sql_build_query('SELECT', $sql_ary), 5);

			$last_news = array();
			while ($row = $this->db->sql_fetchrow($result))
			{
				$last_news[] = $row;
			}
	  
			$this->db->sql_freeresult($result);
			// Cache for 0,5 min.
			$this->cache->put('_recent_news', $last_news, 30);
		}
 
		foreach($last_news as $row)
		{
	
			/* only auth'd users can view the profile */
			$top_users_string = ($this->auth->acl_get('u_viewprofile')) ? get_username_string('full', $row['user_id'], $row['username'], $row['user_colour']) : get_username_string('no_profile', $row['user_id'], $row['username'], $row['user_colour']);

			/* Let's show the TPOTM then.. */
			$new_msgs = (int) $row['post_text'];

			$post_id = $row['post_id'];
			$uid = $bitfield = $options = '';
			$allow_bbcode = $allow_smilies = $allow_urls = true;
			$flags = (($allow_bbcode) ? OPTION_FLAG_BBCODE : 0) + (($allow_smilies) ? OPTION_FLAG_SMILIES : 0) + (($allow_urls) ? OPTION_FLAG_LINKS : 0);
			$message = generate_text_for_display($row['post_text'], $row['bbcode_uid'], $row['bbcode_bitfield'], $flags);
			$msg_chars  = '60';
			if ($msg_chars != 0 and utf8_strlen($message) > $msg_chars)
			{
				$allow_bbcode = $allow_smilies = $allow_urls = false;
				strip_bbcode($message, $row['bbcode_uid']);
				$msg_full = utf8_substr($message, 0, $msg_chars) . '...';
				$msg_full = $msg_full . '...'; 
				$post_link = append_sid("{$this->phpbb_root_path}viewtopic.$this->php_ext", "p=" . $post_id . "#p" . $post_id);
				$read_full = $this->user->lang['READ_FULL'];
			}
			else
			{
				$msg_full = $message;
				$post_link 	= '';
				$read_full 	= '';
			}
			
			$avatar_size_size = $this->config['avatar_re_size'];

			$this->template->assign_block_vars('lastnews',array(
				'LASTPOSTER_NAME'	=> $top_users_string,
				'TOPIC_TITLE'		=> $row['topic_title'],
				'DATE'				=> $this->user->format_date($row['post_time']),
				'TOP_MSG'			=> $msg_full,
				'L_READ_FULL'		=> $read_full,
				'U_READ_FULL'		=> $post_link,
				'POSTER_AVATAR' 	=> ($row['user_avatar']) ? get_user_avatar($row['user_avatar'], $row['user_avatar_type'], ($row['user_avatar_width'] > $row['user_avatar_height']) ? $avatar_size_size : ($avatar_size_size / $row['user_avatar_height']) * $row['user_avatar_width'], ($row['user_avatar_height'] > $row['user_avatar_width']) ? $avatar_size_size : ($avatar_size_size / $row['user_avatar_width']) * $row['user_avatar_height']) : '',
			));
		}
	}
	
	public function topusers()
	{
		/* Check cached data */
		if (($top_posts = $this->cache->get('_top_posts')) === false)
		{
			$topusers_nmb = $this->config['topusers_display_nmb'];

			$sql = 'SELECT u.username, u.user_id, u.user_colour, u.user_type, u.user_avatar, u.user_avatar_type, u.user_avatar_width, u.user_avatar_height, u.user_rank, u.user_posts, p.poster_id, p.post_time, COUNT(p.post_id) AS total_posts
				FROM ' . USERS_TABLE . ' u, ' . POSTS_TABLE . ' p
				WHERE u.user_id > ' . ANONYMOUS . '
					AND u.user_id = p.poster_id
				GROUP BY u.user_id
				ORDER BY total_posts DESC, p.post_time DESC, p.post_id DESC';
			$result = $this->db->sql_query_limit($sql, $topusers_nmb);
			
			$top_posts = array();
	
			while ($row = $this->db->sql_fetchrow($result))
			{
				$top_posts[] = $row;
			}
	  
			$this->db->sql_freeresult($result);

			// Cache for 5 min.
			$this->cache->put('_top_posts', $top_posts, 300);
		}

		foreach( $top_posts as $row )
		{
			get_user_rank($row['user_rank'], $row['user_posts'], $row['rank_title'], $row['rank_image'], $row['rank_image_src']);

			/* Let's show the TPOTM then.. */
			$top_posts = (int) $row['total_posts'];

			/* only auth'd users can view the profile */
			$top_users_string = ($this->auth->acl_get('u_viewprofile')) ? get_username_string('full', $row['user_id'], $row['username'], $row['user_colour']) : get_username_string('no_profile', $row['user_id'], $row['username'], $row['user_colour']);

			/* Fresh install or when a new Month starts gives zero posts */
			$top_nobody = $this->user->lang['TOP_NOBODY'];

			$topuser_name = ($top_posts < 1) ? $top_nobody : $top_users_string;
			$avatar_size_size = $this->config['avatar_re_size'];

			$this->template->assign_block_vars('top_users',array(
				'TOPUSER_NAME'		=> $topuser_name,
				'RANK_TITLE'		=> $row['rank_title'],
				'TOP_POST'			=> $top_posts,
				'S_SEARCH_ACTION'	=> append_sid("{$this->phpbb_root_path}search.$this->php_ext", 'author_id=' . $row['user_id'] . '&amp;sr=posts'),
				'USER_AVATAR_THUMB'   	=>   ($row['user_avatar']) ? get_user_avatar($row['user_avatar'], $row['user_avatar_type'], ($row['user_avatar_width'] > $row['user_avatar_height']) ? $avatar_size_size : ($avatar_size_size / $row['user_avatar_height']) * $row['user_avatar_width'], ($row['user_avatar_height'] > $row['user_avatar_width']) ? $avatar_size_size : ($avatar_size_size / $row['user_avatar_width']) * $row['user_avatar_height']) : '',
			));
		}
	           // END TOPUSERS BLOCK
		// USER MENU BLOCK
		if($this->user->data['is_registered'])
		{
			// Get user info from the browser sessions...
			$user_id = $this->user->data['user_id'];
			$username = $this->user->data['username'];

			// grab user data from database based on info retrieved above
			$sql = 'SELECT *
				FROM ' . USERS_TABLE . '
				WHERE ' . (($username) ? "username_clean = '" . $this->db->sql_escape(utf8_clean_string($username)) . "'" : "user_id = $user_id");
			$result = $this->db->sql_query($sql);
			$member = $this->db->sql_fetchrow($result);

			// set variables retrieved from database query
			$username = $member['username'];
			$user_id = (int) $member['user_id'];
			$colour = $member['user_colour'];

			$sql = 'SELECT rank_title, rank_image FROM ' . RANKS_TABLE . ' WHERE rank_id = ' . (int)$member['user_rank'] . ' LIMIT 1';
			$result = $this->db->sql_query($sql);
			if(($row = $this->db->sql_fetchrow($result)))
			{
				$rank_title = $row['rank_title'];
				$rank_img = $row['rank_image'];
			}
			else
			{
				$rank_title = $rank_img = '';
			}
			$rank = $this->db->sql_freeresult($result);

			// Assign specific vars
			$this->template->assign_vars(array(
				'USERNAME_FULL'      	=> get_username_string('full', $user_id, $username, $colour),
				'USERNAME'            	=> get_username_string('username', $user_id, $username, $colour),
				'USER_COLOR'         	=> $member['user_colour'],
				'USER_AVATAR_SIDE'  	=> get_user_avatar($member['user_avatar'], $member['user_avatar_type'], $member['user_avatar_width'], $member['user_avatar_height']),
				'RANK_TITLE_SIDE'   	=> $rank_title,
				'RANK_IMG_SRC' 			=> $this->phpbb_root_path . 'images/ranks/' . $rank_img,
				'U_VIEW_PROFILE'     	=> $this->phpbb_root_path.'memberlist.php?mode=viewprofile&u='.$user_id,
				'U_PRIVATE_MESSAGES' 	=> append_sid($this->phpbb_root_path.'ucp.' . $this->php_ext . '?i=pm&folder=inbox'),
				'U_COMPOSE_MESSAGES' 	=> append_sid($this->phpbb_root_path.'ucp.' . $this->php_ext . '?i=ucp_pm&mode=compose'),
				'U_MANAGE_PM_DRAFTS' 	=> append_sid($this->phpbb_root_path.'ucp.' . $this->php_ext . '?i=ucp_pm&mode=drafts'),
				'U_INBOX' 	=> append_sid($this->phpbb_root_path.'ucp.' . $this->php_ext . '?i=ucp_pm'),
				'U_OUTBOX' 	=> append_sid($this->phpbb_root_path.'ucp.' . $this->php_ext . '?i=pm&folder=outbox'),
				'U_SENT_MESSAGES' 	=> append_sid($this->phpbb_root_path.'ucp.' . $this->php_ext . '?i=pm&folder=sentbox'),
				'U_RULES_FOLDERS_SETTINGS' 	=> append_sid($this->phpbb_root_path.'ucp.' . $this->php_ext . '?i=ucp_pm&mode=options'),
				'U_LOGIN_LOGOUT'      	=> $this->phpbb_root_path.'ucp.'.$this->php_ext.'?mode=logout&subdir=1&sid='.$this->user->data['session_id'],
				'U_NEW_POSTS'         	=> append_sid($this->phpbb_root_path.'search.' . $this->php_ext . '?search_id=newposts'),
				'U_SELF_POSTS'       	=> append_sid($this->phpbb_root_path.'search.' . $this->php_ext . '?search_id=egosearch'),
			));
		}
	}
       	      // END USER MENU BLOCK
       	      // GROUPS BLOCK
	public function groups_side()
	{
		$order_legend = ($this->config['legend_sort_groupname']) ? 'group_name' : 'group_legend';

		if ($this->auth->acl_gets('a_group', 'a_groupadd', 'a_groupdel'))
		{
			$sql = 'SELECT group_id, group_name, group_colour, group_type, group_legend
				FROM ' . GROUPS_TABLE . '
				WHERE group_legend >= 1
				ORDER BY ' . $order_legend . ' ASC';
		}
		else
		{
			$sql = 'SELECT g.group_id, g.group_name, g.group_colour, g.group_type, g.group_legend
				FROM ' . GROUPS_TABLE . ' g
				LEFT JOIN ' . USER_GROUP_TABLE . ' ug
					ON (
						g.group_id = ug.group_id
						AND ug.user_id = ' . $this->user->data['user_id'] . '
						AND ug.user_pending = 0
					)
				WHERE g.group_legend >= 1
					AND (g.group_type <> ' . GROUP_HIDDEN . ' OR ug.user_id = ' . $this->user->data['user_id'] . ')
				ORDER BY g.' . $order_legend . ' ASC';
		}
		$result = $this->db->sql_query($sql, 600);

		while ($row = $this->db->sql_fetchrow($result))
		{
			$groups[$row['group_id']] = array(
				'group_name'	=> $row['group_name'],
				'group_colour'	=> $row['group_colour'],
				'group_type'	=> $row['group_type'],
				'group_users'	=> array(),
			);
				$legends[] = $row['group_id'];
		}
		$this->db->sql_freeresult($result);

		if (sizeof($legends))
		{
			$sql = 'SELECT
						u.user_id AS user_id, u.username AS username, u.username_clean AS username_clean,
						u.user_colour AS user_colour, ug.group_id AS group_id
					FROM
						' . USERS_TABLE . ' AS u,
						' . USER_GROUP_TABLE . ' AS ug
					WHERE
						ug.user_id = u.user_id
						AND '. $this->db->sql_in_set('ug.group_id', $legends) . '
					ORDER BY u.username_clean ASC';
			$result = $this->db->sql_query($sql, 600);

			while ($row = $this->db->sql_fetchrow($result))
			{
				$groups[$row['group_id']]['group_users'][] = array(
					'user_id'		=> $row['user_id'],
					'username'		=> $row['username'],
					'user_colour'	=> $row['user_colour'],
				);
			}
			$this->db->sql_freeresult($result);
		}

		if (sizeof($groups))
		{
			foreach ($groups as $group_id => $group)
			{
				if (sizeof($group['group_users']))
				{
					$group_name = ($group['group_type'] == GROUP_SPECIAL) ? $this->user->lang['G_' . $group['group_name']] : $group['group_name'];
					$u_group = append_sid("{$this->phpbb_root_path}memberlist.{$this->php_ext}", 'mode=group&amp;g=' . $group_id);

					$this->template->assign_block_vars('group', array(
						'GROUP_NAME'	=> $group_name,
						'GROUP_COLOUR'	=> $group['group_colour'],
						'U_GROUP'		=> $u_group,
					));

					foreach ($group['group_users'] as $group_user)
					{
						$this->template->assign_block_vars('group.member', array(
							'USER_ID'			=> $group_user['user_id'],
							'USERNAME_FULL'		=> get_username_string('full', $group_user['user_id'], $group_user['username'], $group_user['user_colour']),
						));
					}
				}
			}
		}

		$sql = $this->db->sql_build_query('SELECT', array(
			'SELECT'	=> 'u.user_id, u.group_id as default_group, u.username, u.user_colour, u.user_allow_pm, g.group_id, g.group_name, g.group_colour, g.group_type, g.group_legend, ug.user_id as ug_user_id',
			'FROM'		=> array(
				USERS_TABLE		=> 'u',
				GROUPS_TABLE	=> 'g'
			),
			'LEFT_JOIN'	=> array(
				array(
					'FROM'	=> array(USER_GROUP_TABLE => 'ug'),
					'ON'	=> 'ug.group_id = g.group_id AND ug.user_pending = 0 AND ug.user_id = ' . $this->user->data['user_id']
				)),
			'WHERE'		=> 'u.group_id = g.group_id AND ' . $this->db->sql_in_set('g.group_name', array('ADMINISTRATORS', 'GLOBAL_MODERATORS')),
			'ORDER_BY'	=> 'g.' . $order_legend . ' ASC, u.username_clean ASC'
		));

		$result = $this->db->sql_query($sql, 600);

		while ($row = $this->db->sql_fetchrow($result))
		{
			if ($row['group_name'] == 'ADMINISTRATORS')
			{
				$which_row = 'admins';
			}
			if ($row['group_name'] == 'GLOBAL_MODERATORS')
			{
				$which_row = 'moderators';
			}
			else
			{
				continue;
			}

			if ($row['group_type'] == GROUP_HIDDEN && !$this->auth->acl_gets('a_group', 'a_groupadd', 'a_groupdel') && $row['ug_user_id'] != $this->user->data['user_id'])
			{
				$group_name = $this->user->lang['GROUP_UNDISCLOSED'];
				$u_group = '';
			}
			else
			{
				$group_name = ($row['group_type'] == GROUP_SPECIAL) ? $this->user->lang['G_' . $row['group_name']] : $row['group_name'];
				$u_group = append_sid("{$this->phpbb_root_path}memberlist.{$this->php_ext}", 'mode=group&amp;g=' . $row['group_id']);
			}

			$this->template->assign_block_vars($which_row, array(
				'USER_ID'			=> $row['user_id'],
				'GROUP_NAME'		=> $group_name,
				'GROUP_COLOR'		=> $row['group_colour'],
				'U_GROUP'			=> $u_group,
				'USERNAME_FULL'		=> get_username_string('full', $row['user_id'], $row['username'], $row['user_colour']),
				'USERNAME'			=> get_username_string('username', $row['user_id'], $row['username'], $row['user_colour']),
				'USER_COLOR'		=> get_username_string('colour', $row['user_id'], $row['username'], $row['user_colour']),
				'U_VIEW_PROFILE'	=> get_username_string('profile', $row['user_id'], $row['username'], $row['user_colour']),
			));
		}
	    // END GROUPS BLOCK
	}
	
	public function random_member()
	{
		switch ($this->db->get_sql_layer())
		{
			case 'postgres':
			$sql = 'SELECT *
				FROM ' . USERS_TABLE . '
				WHERE user_type <> ' . USER_IGNORE . '
				AND user_type <> ' . USER_INACTIVE . '
				ORDER BY RANDOM()';
			break;

			case 'mssql':
			case 'mssql_odbc':
			$sql = 'SELECT *
				FROM ' . USERS_TABLE . '
				WHERE user_type <> ' . USER_IGNORE . '
				AND user_type <> ' . USER_INACTIVE . '
				ORDER BY NEWID()';
			break;

			default:
			$sql = 'SELECT *
				FROM ' . USERS_TABLE . '
				WHERE user_type <> ' . USER_IGNORE . '
				AND user_type <> ' . USER_INACTIVE . '
				ORDER BY RAND()';
			break;
		}

		$result = $this->db->sql_query_limit($sql, 1);
		$row = $this->db->sql_fetchrow($result);

		$avatar_img = phpbb_get_avatar(\phpbb\avatar\manager::clean_row($row, 'user'), 'USER_AVATAR');

		$rank_title = $rank_img = $rank_img_src = '';
		get_user_rank($row['user_rank'], $row['user_posts'], $rank_title, $rank_img, $rank_img_src);

		$username = $row['username'];
		$user_id = (int) $row['user_id'];
		$colour = $row['user_colour'];

		$this->template->assign_block_vars('random_member', array(
			'USERNAME_FULL'		=> get_username_string('full', $user_id, $username, $colour),
			'USERNAME'			=> get_username_string('username', $user_id, $username, $colour),
			'USER_COLOR'		=> get_username_string('colour', $user_id, $username, $colour),
			'U_VIEW_PROFILE'	=> get_username_string('profile', $user_id, $username, $colour),

			'RANK_TITLE'	=> $rank_title,
			'RANK_IMG'		=> $rank_img,
			'RANK_IMG_SRC'	=> $rank_img_src,

			'USER_POSTS'	=> (int) $row['user_posts'],
			'AVATAR_IMG'	=> $avatar_img,
			'JOINED'		=> $this->user->format_date($row['user_regdate']),
			//'USER_OCC'		=> censor_text($row['user_occ']),
			//'USER_FROM'		=> censor_text($row['user_from']),
			//'U_WWW'			=> censor_text($row['user_website']),
		));
	}
}
